b4c59514f00bdfba0db99fed67740ef8858ac583
hiram
  Mon Mar 2 13:13:28 2020 -0800
correct one line header message in usage() refs #25071

diff --git src/utils/rmFaDups/rmFaDups.c src/utils/rmFaDups/rmFaDups.c
index c76a069..60de721 100644
--- src/utils/rmFaDups/rmFaDups.c
+++ src/utils/rmFaDups/rmFaDups.c
@@ -1,32 +1,32 @@
 /* rmFaDup - remove duplicate records from FA file. */
 
 /* Copyright (C) 2011 The Regents of the University of California 
  * See README in this or parent directory for licensing information. */
 #include "common.h"
 #include "fa.h"
 #include "hash.h"
 #include "obscure.h"
 
 
 void usage()
 /* Print usage and exit. */
 {
 errAbort(
-  "rmFaDup - remove duplicate records in FA file\n"
+  "rmFaDups - remove duplicate records in FA file\n"
   "usage\n"
-  "   rmFaDup oldName.fa newName.fa\n");
+  "   rmFaDups oldName.fa newName.fa\n");
 }
 
 void rmFaDups(char *inFile, char *outFile)
@@ -1,32 +1,32 @@
-/* rmFaDup - remove duplicate records from FA file. */
+/* rmFaDups - remove duplicate records from FA file. */
 
 /* Copyright (C) 2011 The Regents of the University of California 
 /* undupFa - remove duplicate records from FA file. */
 {
 struct hash *uniq = newHash(0);
 struct hashEl *hel;
 char *name;
 FILE *in = mustOpen(inFile, "r");
 FILE *out = mustOpen(outFile, "w");
 DNA *dna;
 int size;
 
 
 while (faFastReadNext(in, &dna, &size, &name))